betty.ancestry.place_type package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.place_type package

## Submodules

- betty.ancestry.place_type.place_types module
  - `Borough`
  - `Building`
  - `City`
  - `Country`
  - `County`
  - `Department`
  - `District`
  - `Farm`
  - `Hamlet`
  - `Locality`
  - `Municipality`
  - `Neighborhood`
  - `Number`
  - `Parish`
  - `Province`
  - `Region`
  - `State`
  - `Street`
  - `Town`
  - `Unknown`
  - `Village`

## Module contents

Provide Betty’s ancestry place types.

betty.ancestry.place_type.PLACE_TYPE_REPOSITORY: PluginRepository[PlaceType] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The place type plugin repository.

  Read more about Place type plugins.

class betty.ancestry.place_type.PlaceType

  Bases: `Plugin`

  Define an `betty.ancestry.place.Place` type.

  Read more about Place type plugins.

  To test your own subclasses, use `betty.test_utils.ancestry.place_type.PlaceTypeTestBase`.